powered by
This function initializes an in-memory scouting workflow. It does not create any directories or write files.
init_real_scout()
NULL. Called for side effects only.
This function is retained for API compatibility but performs no file system operations in order to comply with CRAN policies.
Run the code above in your browser using DataLab